use crate::{
    config::UserConfig,
    linux::{arch_chroot, install_file},
    print_status,
};

pub fn change_passwd(user: &str, pw: &str) {
    arch_chroot(&["passwd", user], Some(&format!("{}\n{}\n", pw, pw)), false);
}

/// Setup the users of the system
pub fn setup_users(conf: &[UserConfig]) {
    let mut doas_conf = String::new();

    for user in conf {
        let mut cmd = vec!["useradd"];

        if let Some(home_dir) = &user.home_dir {
            if home_dir.is_empty() {
                cmd.push("-M");
            } else {
                cmd.push("-m");
                cmd.push("-d");
                cmd.push(home_dir);
            }
        } else {
            cmd.push("-m");
        }

        let uid = user.uid.map(|x| x.to_string());

        if let Some(uid) = &uid {
            cmd.push("-u");
            cmd.push(uid);
        }

        if let Some(shell) = &user.shell {
            cmd.push("-s");
            cmd.push(shell);
        }

        cmd.push(&user.name);

        arch_chroot(&cmd, None, false);

        change_passwd(&user.name, &user.password);

        if user.doas_root.unwrap_or_default() {
            print_status(&format!("Allowing root doas for {}", user.name));
            doas_conf.push_str(&format!("permit {} as root\n", user.name));
        }
    }

    install_file("/mnt/etc/doas.conf", &doas_conf, 0o644);
}
